@@ -7,7 +7,7 @@
 # http://search.cpan.org/dist/Devel-NYTProf/
 #
 ###########################################################
-# $Id: Util.pm 646 2008-12-09 16:00:18Z tim.bunce $
+# $Id: Util.pm 691 2009-03-05 14:37:52Z tim.bunce $
 ###########################################################
 package Devel::NYTProf::Util;
 
@@ -40,7 +40,7 @@ use Cwd qw(getcwd);
 use List::Util qw(sum);
 use UNIVERSAL qw( isa can VERSION );
 
-our $VERSION = '2.07';
+our $VERSION = '2.08';
 
 our @EXPORT_OK = qw(
     fmt_float
@@ -216,8 +216,13 @@ sub calculate_median_absolute_deviation {
 
 sub html_safe_filename {
     my ($fname) = @_;
-    $fname =~ s{ ^[/\\] }{}x;                      # remove leading / or \
-    $fname =~ s{  [/\\] }{-}xg;                    # replace / and \ with html safe -
+    # replace / and \ with html safe '-', we also do a bunch of other
+    # chars, especially ':' for Windows, to make the namer simpler and safer
+    # also remove dots to keep VMS happy
+    $fname =~ s{  [-/\\:\*\?"'<>|.]+ }{-}xg;
+    # remove any leading or trailing '-' chars
+    $fname =~ s{^-}{};
+    $fname =~ s{-$}{};
     return $fname;
 }
 
